import { PDFDocumentProxy, AbortException, MissingPDFException, InvalidPDFException, RenderingCancelledException, UnexpectedResponseException } from "pdfjs-dist";
import { EventBus, PDFViewer, PDFLinkService, DownloadManager, PDFFindController, PDFPageView } from "pdfjs-dist/web/pdf_viewer.mjs";
import { IL10n } from "pdfjs-dist/types/web/pdf_viewer";
import type { PDFSlickInputArgs, PDFSlickState, TEventBusName, TEventBusOptions, TEventBusListener } from "./types";
import { PDFThumbnailViewer, PDFPresentationMode } from "./lib";
import { StoreApi } from "zustand/vanilla";
export type PDFException = AbortException | MissingPDFException | InvalidPDFException | RenderingCancelledException | UnexpectedResponseException;
export declare class PDFSlick {
    #private;
    printService: any;
    url: string | ArrayBuffer | undefined;
    eventBus: EventBus;
    linkService: PDFLinkService;
    downloadManager: DownloadManager | null;
    findController: PDFFindController | null;
    pdfPresentationMode: PDFPresentationMode | null;
    viewer: PDFViewer;
    thumbnailViewer?: PDFThumbnailViewer;
    document: PDFDocumentProxy | null;
    store: StoreApi<PDFSlickState>;
    filename: string;
    l10n: IL10n;
    singlePageViewer: boolean;
    removePageBorders: boolean;
    enablePrintAutoRotate: boolean;
    useOnlyCssZoom: boolean;
    pageColors: {
        background: any;
        foreground: any;
    } | null;
    annotationEditorHighlightColors: string | undefined;
    textLayerMode: number;
    maxCanvasPixels: number;
    printResolution: number;
    thumbnailWidth: number;
    constructor({ container, viewer, thumbs, store, options, onError }: PDFSlickInputArgs);
    loadDocument(url: string | URL | ArrayBuffer, options?: {
        filename?: string;
    }): Promise<void>;
    forceRendering(isThumbnailViewEnabled?: boolean): void;
    gotoPage(pageNumber: number): void;
    openOrDownloadData(data: Uint8Array, filename: string): void;
    download(): Promise<void>;
    save(): Promise<void>;
    downloadOrSave(): void;
    get supportsPrinting(): boolean;
    beforePrint(): void;
    afterPrint(): void;
    requestPresentationMode(): void;
    triggerPrinting(): void;
    _cleanup(): void;
    setAnnotationEditorMode(annotationEditorMode: number): void;
    setAnnotationEditorParams(annotationEditorParams: {
        type: number;
        value: any;
    } | {
        type: number;
        value: any;
    }[]): void;
    setHighlightDefaultColor(color: string): void;
    setSpreadMode(spread: number): void;
    setScrollMode(scroll: number): void;
    setRotation(rotation: number): void;
    getPagesOverview(): {
        width: number;
        height: number;
        rotation: number;
    }[];
    /**
     * Zoom In
     */
    increaseScale(): void;
    /**
     * Zoom out
     */
    decreaseScale(): void;
    /**
     * Set preset value ("auto", "page-width" wtc)
     */
    set currentScaleValue(val: string);
    /**
     * Set viewer's scale to a number value
     */
    set currentScale(val: number);
    getPageView(ix: number): PDFPageView;
    /**
     * Add event listener on the pdfViewer eventBus
     * @param eventName TEventBusName
     * @param listener TEventBusListener
     * @param options TEventBusOptions
     */
    on(eventName: TEventBusName, listener: TEventBusListener, options?: TEventBusOptions): void;
    /**
     * Remove event listener from the pdfViewer eventBus
     * @param eventName TEventBusName
     * @param listener TEventBusListener
     * @param options TEventBusOptions
     */
    off(eventName: TEventBusName, listener: TEventBusListener, options?: TEventBusOptions): void;
    /**
     * Dispatch event on the eventBus
     * @param eventName TEventBusName
     * @param data Object
     */
    dispatch(eventName: TEventBusName, data: Object): void;
}
//# sourceMappingURL=PDFSlick.d.ts.map